@@ -4,7 +4,7 @@
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "gcompris/gcompris.h"
@@ -175,7 +174,7 @@ colors_config_start(GcomprisBoard *agcomprisBoard,
   gchar *saved_locale_sound = g_hash_table_lookup( config, "locale_sound");
 
   gc_board_config_combo_locales_asset( _("Select sound locale"), saved_locale_sound,
-				"sounds/$LOCALE/colors/purple.ogg");
+				"voices/$LOCALE/colors/purple.ogg");
 
   g_hash_table_destroy(config);
 
@@ -221,7 +220,7 @@ static void start_board (GcomprisBoard *agcomprisBoard) {
 
   g_hash_table_destroy(config);
 
-  gc_sound_pause();
+  gc_sound_bg_pause();
 
   if(agcomprisBoard!=NULL) {
     gcomprisBoard=agcomprisBoard;
@@ -284,7 +283,7 @@ static void end_board () {
   }
   gc_locale_reset();
   gcomprisBoard = NULL;
-  gc_sound_resume();
+  gc_sound_bg_resume();
 }
 
 /* =====================================================================
@@ -319,7 +318,7 @@ static void repeat (){
       char *str  = NULL;
       GcomprisProperties *properties = gc_prop_get();
 
-      str = g_strdup_printf("sounds/$LOCALE/colors/%s.ogg",
+      str = g_strdup_printf("voices/$LOCALE/colors/%s.ogg",
 			    colors[GPOINTER_TO_INT(g_list_nth_data(listColors, 0))*2]);
 
       /* If we don't find a sound in our locale or the sounds are disabled */
