@@ -1,12 +1,12 @@
 /* gcompris - memory.c
  *
- * Time-stamp: <2006/08/21 23:33:28 bruno>
+ * Time-stamp: <2007-08-22 01:26:19 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 // FIXME: Cleanup of MemoryItem created struct is not done
@@ -207,51 +206,49 @@ static gchar *imageList[] =
 /* List of sounds to use in the memory */
 static gchar *soundList[] =
 {
-   "sounds/LuneRouge/animaux/LRRain_in_garden_01_by_Lionel_Allorge_cut.ogg",
+   "sounds/LuneRouge/LRLaPause_short.ogg",
    "sounds/LuneRouge/animaux/LRBark_1_by_Lionel_Allorge_cut.ogg",
    "sounds/LuneRouge/animaux/LRBark_3_by_Lionel_Allorge_cut.ogg",
    "sounds/LuneRouge/animaux/LRFrogsInPondDuringStormByLionelAllorgeCut.ogg",
-   "sounds/LuneRouge/engins/LRObject_falling_02_by_Lionel_Allorge.ogg",
-   "sounds/LuneRouge/engins/LRTrain_slowing_down_01_by_Lionel_Allorge_cut.ogg",
-   "sounds/LuneRouge/engins/LRStartAndStopCarEngine1ByLionelAllorgeCut.ogg",
+   "sounds/LuneRouge/animaux/LRRain_in_garden_01_by_Lionel_Allorge_cut.ogg",
    "sounds/LuneRouge/engins/LRObject_falling_01_by_Lionel_Allorge.ogg",
+   "sounds/LuneRouge/engins/LRObject_falling_02_by_Lionel_Allorge.ogg",
+   "sounds/LuneRouge/engins/LRStartAndStopCarEngine1ByLionelAllorgeCut.ogg",
+   "sounds/LuneRouge/engins/LRTrain_slowing_down_01_by_Lionel_Allorge_cut.ogg",
    "sounds/LuneRouge/humain/LRApplauses_1_by_Lionel_Allorge_cut.ogg",
    "sounds/LuneRouge/humain/LRHeart_beat_01_by_Lionel_Allorge.ogg",
    "sounds/LuneRouge/maison/LRDoor_Open_2_by_Lionel_Allorge.ogg",
    "sounds/LuneRouge/maison/LRRing_01_by_Lionel_Allorge.ogg",
    "sounds/LuneRouge/musique/LRBuddhist_gong_05_by_Lionel_Allorge.ogg",
-   "sounds/LuneRouge/sf/LRWeird_4_by_Lionel_Allorge.ogg",
    "sounds/LuneRouge/sf/LRWeird_1_by_Lionel_Allorge.ogg",
    "sounds/LuneRouge/sf/LRWeird_2_by_Lionel_Allorge.ogg",
    "sounds/LuneRouge/sf/LRWeird_3_by_Lionel_Allorge.ogg",
+   "sounds/LuneRouge/sf/LRWeird_4_by_Lionel_Allorge.ogg",
    "sounds/LuneRouge/sf/LRWeird_5_by_Lionel_Allorge.ogg",
    "sounds/LuneRouge/sf/LRWeird_6_by_Lionel_Allorge.ogg",
-   "sounds/LuneRouge/sf/LRET_phone_home_01_by_Lionel_Allorge_cut.ogg",
+   "sounds/LuneRouge/usine/LRFactory_noise_01_by_Lionel_Allorge.ogg",
    "sounds/LuneRouge/usine/LRFactory_noise_02_by_Lionel_Allorge.ogg",
    "sounds/LuneRouge/usine/LRFactory_noise_03_by_Lionel_Allorge.ogg",
    "sounds/LuneRouge/usine/LRFactory_noise_04_by_Lionel_Allorge.ogg",
    "sounds/LuneRouge/usine/LRFactory_noise_05_by_Lionel_Allorge.ogg",
    "sounds/LuneRouge/usine/LRFactory_noise_06_by_Lionel_Allorge.ogg",
-   "sounds/LuneRouge/usine/LRHits_01_by_Lionel_Allorge.ogg",
    "sounds/LuneRouge/usine/LRFireballs_01_by_Lionel_Allorge.ogg",
-   "sounds/LuneRouge/usine/LRFactory_noise_01_by_Lionel_Allorge.ogg",
-   "sounds/LuneRouge/LRLaPause_short.ogg",
-   "sounds/memory/plick.ogg",
-   "sounds/memory/tick.ogg",
-   "sounds/memory/tri.ogg",
+   "sounds/LuneRouge/usine/LRHits_01_by_Lionel_Allorge.ogg",
    "sounds/chronos/space/1.ogg",
    "sounds/chronos/space/2.ogg",
-   "sounds/chronos/space/2.ogg",
    "sounds/melody/guitar/melody.ogg",
    "sounds/melody/guitar/son1.ogg",
    "sounds/melody/guitar/son2.ogg",
    "sounds/melody/guitar/son3.ogg",
    "sounds/melody/guitar/son4.ogg",
+   "sounds/melody/tachos/melody.ogg",
    "sounds/melody/tachos/son1.ogg",
    "sounds/melody/tachos/son2.ogg",
    "sounds/melody/tachos/son3.ogg",
    "sounds/melody/tachos/son4.ogg",
-   "sounds/melody/tachos/melody.ogg"
+   "sounds/memory/plick.ogg",
+   "sounds/memory/tick.ogg",
+   "sounds/memory/tri.ogg",
 };
 
 #define NUMBER_OF_SOUNDS G_N_ELEMENTS(soundList)
@@ -794,7 +791,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 	{
 	  GcomprisProperties	*properties = gc_prop_get();
 
-	  gc_sound_pause();
+	  gc_sound_bg_pause();
 
 	  /* initial state to restore */
 	  sound_policy = gc_sound_policy_get();
@@ -886,7 +883,7 @@ end_board ()
 {
   if (currentUiMode == UIMODE_SOUND) {
     gc_sound_policy_set(sound_policy);
-    gc_sound_resume();
+    gc_sound_bg_resume();
   }
 
   if(gcomprisBoard!=NULL)
