@@ -1,4 +1,5 @@
 #include "py-gcompris-properties.h"
+#define NO_IMPORT_PYGOBJECT 1
 #include <pygobject.h>
 #include "py-gcompris-profile.h"
 #include "py-gcompris-board.h"
@@ -97,10 +98,12 @@ pyGcomprisPropertiesType_getattr(pyGcomprisPropertiesObject *self, char *name)
     if(strcmp(name,"root_menu")==0) return Py_BuildValue("s", self->cdata->root_menu);
     if(strcmp(name,"local_directory")==0) return Py_BuildValue("s", self->cdata->local_directory);
     if(strcmp(name,"package_data_dir")==0) return Py_BuildValue("s", self->cdata->package_data_dir);
+    if(strcmp(name,"package_plugin_dir")==0) return Py_BuildValue("s", self->cdata->package_plugin_dir);
+    if(strcmp(name,"package_python_plugin_dir")==0) return Py_BuildValue("s", self->cdata->package_python_plugin_dir);
     if(strcmp(name,"locale")==0) return Py_BuildValue("s", self->cdata->locale);
     if(strcmp(name,"skin")==0) return Py_BuildValue("s", self->cdata->skin);
-    if(strcmp(name,"shared_dir")==0) return Py_BuildValue("s", self->cdata->shared_dir);
-    if(strcmp(name,"users_dir")==0) return Py_BuildValue("s", self->cdata->users_dir);
+    if(strcmp(name,"config_dir")==0) return Py_BuildValue("s", self->cdata->config_dir);
+    if(strcmp(name,"user_dir")==0) return Py_BuildValue("s", self->cdata->user_dir);
 
     if(strcmp(name,"profile")==0){
       if (self->cdata->profile)
