@@ -4,7 +4,7 @@
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <Python.h>
@@ -61,7 +60,7 @@ static BoardPlugin menu_bp =
     NULL,
     NULL,
     N_("Python Board"),
-    N_("Special board that embeds python into gcompris."),
+    N_("Special board that embeds python into GCompris."),
     "Olivier Samyn <osamyn@ulb.ac.be>",
     pythonboard_init,
     NULL,
@@ -85,7 +84,7 @@ static BoardPlugin menu_bp_no_config =
     NULL,
     NULL,
     N_("Python Board"),
-    N_("Special board that embeds python into gcompris."),
+    N_("Special board that embeds python into GCompris."),
     "Olivier Samyn <osamyn@ulb.ac.be>",
     pythonboard_init,
     NULL,
