@@ -1,12 +1,12 @@
 #  gcompris - melody
 #
-# Time-stamp: <2005/03/05 jose>
+# Time-stamp: <2007-08-22 01:26:07 bruno>
 #
 # Copyright (C) 2003 Jose Jorge
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation; either version 2 of the License, or
+#   the Free Software Foundation; either version 3 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -15,9 +15,9 @@
 #   GNU General Public License for more details.
 #
 #   You should have received a copy of the GNU General Public License
-#   along with this program; if not, write to the Free Software
-#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#   along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
+import gobject
 import gnomecanvas
 import gcompris
 import gcompris.utils
@@ -133,7 +133,7 @@ class Gcompris_melody:
 
     # Clear all timer
     for i in self.timers :
-      gtk.timeout_remove(i)
+      gobject.source_remove(i)
 
     self.timers = []
 
@@ -246,7 +246,7 @@ class Gcompris_melody:
   def repeat(self):
     #print("Gcompris_melody repeat.")
     # Important to use a timer here to keep self.timers up todate
-    self.timers.append(gtk.timeout_add(50, self.repeat_it))
+    self.timers.append(gobject.timeout_add(50, self.repeat_it))
 
   def repeat_it(self):
     #print("Gcompris_melody repeat it.")
@@ -263,12 +263,12 @@ class Gcompris_melody:
     timer = 0
 
     for i in self.solution:
-      self.timers.append(gtk.timeout_add(timer, self.show_bang, i))
+      self.timers.append(gobject.timeout_add(timer, self.show_bang, i))
       timer = timer + 1000
-      self.timers.append(gtk.timeout_add(timer, self.show_bang_stop, i))
+      self.timers.append(gobject.timeout_add(timer, self.show_bang_stop, i))
       timer = timer + 500
 
-    self.timers.append(gtk.timeout_add(timer, self.ready))
+    self.timers.append(gobject.timeout_add(timer, self.ready))
 
 
   def config(self):
@@ -283,7 +283,7 @@ class Gcompris_melody:
     for i in range(self.gcomprisBoard.level+2):
       self.solution.append(sound_struct[random.randint(0,len(sound_struct)-1)])
 
-    self.timers.append(gtk.timeout_add(1300, self.repeat_it))
+    self.timers.append(gobject.timeout_add(1300, self.repeat_it))
 
   def key_press(self, keyval, commit_str, preedit_str):
     #print("got key %i" % keyval)
