@@ -4,7 +4,7 @@
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation; either version 2 of the License, or
+#   the Free Software Foundation; either version 3 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
 #   GNU General Public License for more details.
 #
 #   You should have received a copy of the GNU General Public License
-#   along with this program; if not, write to the Free Software
-#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#   along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
 import gnomecanvas
 import gcompris
@@ -141,7 +140,9 @@ class Gcompris_tuxpaint:
             flags=flags)
 
     except:
-       gcompris.utils.dialog(_("Cannot find Tuxpaint.\nInstall it to use this activity !"),stop_board)
+       restore_grab(self)
+       gcompris.utils.dialog(_("Cannot find Tuxpaint.\nInstall it to use this activity !"),
+                             stop_board)
        return
 
     gobject.child_watch_add(pid, child_callback, data=self, priority=gobject.PRIORITY_HIGH)
@@ -207,26 +208,33 @@ class Gcompris_tuxpaint:
                                                    self.apply_callback)
 
 
-    gcompris.boolean_box(_('Inherit fullscreen setting from GCompris'), 'fullscreen', eval(self.config_dict['fullscreen']))
+    gcompris.boolean_box(_('Inherit fullscreen setting from GCompris'), 'fullscreen',
+                         eval(self.config_dict['fullscreen']))
 
     gcompris.separator()
 
-    gcompris.boolean_box(_('Inherit size setting from GCompris (800x600, 640x480)'), 'size', eval(self.config_dict['size']))
+    gcompris.boolean_box(_('Inherit size setting from GCompris (800x600, 640x480)'),
+                         'size', eval(self.config_dict['size']))
 
     gcompris.separator()
 
-    gcompris.boolean_box(_('Disable shape rotation'), 'disable_shape_rotation', eval(self.config_dict['disable_shape_rotation']))
+    gcompris.boolean_box(_('Disable shape rotation'), 'disable_shape_rotation',
+                         eval(self.config_dict['disable_shape_rotation']))
 
     gcompris.separator()
 
-    gcompris.boolean_box(_('Show Uppercase text only'), 'uppercase_text', eval(self.config_dict['uppercase_text']))
+    gcompris.boolean_box(_('Show Uppercase text only'), 'uppercase_text',
+                         eval(self.config_dict['uppercase_text']))
 
     gcompris.separator()
 
-    stamps = gcompris.boolean_box(_('Disable stamps'), 'disable_stamps', eval(self.config_dict['disable_stamps']))
+    stamps = gcompris.boolean_box(_('Disable stamps'), 'disable_stamps',
+                                  eval(self.config_dict['disable_stamps']))
     stamps.connect("toggled", self.stamps_changed)
 
-    self.stamps_control = gcompris.boolean_box('Disable stamps control', 'disable_stamps_control', eval(self.config_dict['disable_stamps_control']))
+    self.stamps_control = gcompris.boolean_box('Disable stamps control',
+                                               'disable_stamps_control',
+                                               eval(self.config_dict['disable_stamps_control']))
     self.stamps_control.set_sensitive(not eval(self.config_dict['disable_stamps']))
 
   def stamps_changed(self, button):
@@ -246,7 +254,7 @@ class Gcompris_tuxpaint:
       }
     return default_config_dict
 
-def child_callback(fd,  cond, data):
+def restore_grab(data):
   # restore pointergrab if running fullscreen
   if (gcompris.get_properties().fullscreen and
       not gcompris.get_properties().noxf86vm):
@@ -257,11 +265,15 @@ def child_callback(fd,  cond, data):
        data.window.unfullscreen()
        data.window.fullscreen()
 
+
+def child_callback(fd,  cond, data):
+  restore_grab(data)
   global pid
   pid = None
   gcompris.bar_hide(0)
   gcompris.bonus.board_finished(gcompris.bonus.FINISHED_RANDOM)
 
 def stop_board():
+  gcompris.bar_hide(0)
   gcompris.bonus.board_finished(gcompris.bonus.FINISHED_RANDOM)
 
