@@ -363,7 +363,7 @@ is_our_board (GcomprisBoard *gcomprisBoard)
  */
 static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
 {
-  if(!gcomprisBoard)
+  if(board_paused || !gcomprisBoard)
     return FALSE;
 
   /* Add some filter for control and shift key */
@@ -941,6 +941,7 @@ static gint item_event_drag(GnomeCanvasItem *item, GdkEvent *event, gpointer dat
                         }
 
                         gc_sound_play_ogg(soundfile, NULL);
+			g_free(soundfile);
                     }
 		    else
 		      gc_sound_play_ogg ("sounds/bleep.wav", NULL);
