@@ -5,7 +5,7 @@
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation; either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
@@ -14,8 +14,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <string.h>
@@ -181,7 +180,7 @@ void gc_board_init(void)
 
   /* First make sure the module loading is supported on this platform */
   if (!g_module_supported())
-    g_error( _("Dynamic module loading is not supported. gcompris cannot load.\n") );
+    g_error( _("Dynamic module loading is not supported. GCompris cannot load.\n") );
 
   bp_data = g_malloc0(sizeof (struct BoardPluginData));
 
@@ -406,7 +405,7 @@ gc_board_stop(void)
 static gboolean
 get_board_playing(void)
 {
-  return bp_data->playing;
+  return (bp_data && bp_data->playing);
 }
 
 static GcomprisBoard *next_board = NULL;
