@@ -1,12 +1,12 @@
 /* gcompris - bonus.c
  *
- * Time-stamp: <2001/10/15 01:10:21 bruno>
+ * Time-stamp: <2007-08-22 01:20:04 bruno>
  *
  * Copyright (C) 2001 Pascal George
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "gcompris.h"
@@ -45,21 +44,21 @@ static int left_door_limit = 0;
 // List of sounds to use for greetings
 static gchar *greetingsList[] =
 {
-  "sounds/$LOCALE/misc/congratulation.ogg",
-  "sounds/$LOCALE/misc/great.ogg",
-  "sounds/$LOCALE/misc/good.ogg",
-  "sounds/$LOCALE/misc/awesome.ogg",
-  "sounds/$LOCALE/misc/fantastic.ogg",
-  "sounds/$LOCALE/misc/waytogo.ogg",
-  "sounds/$LOCALE/misc/super.ogg",
-  "sounds/$LOCALE/misc/perfect.ogg"
+  "voices/$LOCALE/misc/congratulation.ogg",
+  "voices/$LOCALE/misc/great.ogg",
+  "voices/$LOCALE/misc/good.ogg",
+  "voices/$LOCALE/misc/awesome.ogg",
+  "voices/$LOCALE/misc/fantastic.ogg",
+  "voices/$LOCALE/misc/waytogo.ogg",
+  "voices/$LOCALE/misc/super.ogg",
+  "voices/$LOCALE/misc/perfect.ogg"
 };
 #define NUMBER_OF_GREETINGS G_N_ELEMENTS(greetingsList)
 
 // List of sounds to use for loosing
 static gchar *loosingList[] =
 {
-  "sounds/$LOCALE/misc/check_answer.ogg",
+  "voices/$LOCALE/misc/check_answer.ogg",
 };
 #define NUMBER_OF_LOOSING 1
 
@@ -84,7 +83,7 @@ end_gc_bonus_end_display() {
   }
 
   if (gc_bonus_end_display_id) {
-    gtk_timeout_remove(gc_bonus_end_display_id);
+    g_source_remove(gc_bonus_end_display_id);
     gc_bonus_end_display_id = 0;
   }
 
@@ -389,7 +388,7 @@ static void
 end_bonus()
 {
   if (end_bonus_id) {
-    gtk_timeout_remove (end_bonus_id);
+    g_source_remove (end_bonus_id);
     end_bonus_id = 0;
   }
 
