@@ -1,12 +1,12 @@
 /* gcompris - dialog.c
  *
- * Time-stamp: <2006/08/20 09:52:47 bruno>
+ * Time-stamp: <2007-08-22 01:21:28 bruno>
  *
  * Copyright (C) 2000-2006 Bruno Coudoin
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <string.h>
@@ -70,6 +69,12 @@ void gc_dialog(gchar *str, DialogBoxCallBack dbcb)
     return;
   }
 
+  if(gc_get_canvas() == NULL)
+    {
+      g_warning("Cannot run a dialog box, canvas not initialized yet = %s\n", str);
+      return;
+    }
+
   /* First pause the board */
   gc_board_pause(TRUE);
 
@@ -85,11 +90,11 @@ void gc_dialog(gchar *str, DialogBoxCallBack dbcb)
   pixmap_dialog = gc_skin_pixmap_load("dialogbox.png");
 
   itemDialogText = gnome_canvas_item_new (rootDialogItem,
-				       gnome_canvas_pixbuf_get_type (),
-				       "pixbuf", pixmap_dialog,
-				       "x", (double) (BOARDWIDTH - gdk_pixbuf_get_width(pixmap_dialog))/2,
-				       "y", (double) (BOARDHEIGHT - gdk_pixbuf_get_height(pixmap_dialog))/2,
-				      NULL);
+					  gnome_canvas_pixbuf_get_type (),
+					  "pixbuf", pixmap_dialog,
+					  "x", (double) (BOARDWIDTH - gdk_pixbuf_get_width(pixmap_dialog))/2,
+					  "y", (double) (BOARDHEIGHT - gdk_pixbuf_get_height(pixmap_dialog))/2,
+					  NULL);
 
   /* OK Text */
   item_text_ok = gnome_canvas_item_new (rootDialogItem,
