@@ -1,12 +1,12 @@
 /* gcompris - gameutil.c
  *
- * Time-stamp: <2006/08/20 12:41:31 bruno>
+ * Time-stamp: <2007-08-22 01:21:20 bruno>
  *
  * Copyright (C) 2000-2006 Bruno Coudoin
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -96,7 +95,7 @@ GdkPixbuf *gc_pixmap_load(const gchar *format, ...)
       char *str;
 
       if(!pixmap)
-	g_warning("Loading image '%s' returned a null pointer", filename);
+	g_warning("Loading image '%s' returned a null pointer", pixmapfile);
       else
 	g_warning ("Couldn't find file %s !", pixmapfile);
 
