@@ -4,7 +4,7 @@
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <string.h>
@@ -22,9 +21,8 @@
 #include "gcompris.h"
 #include <glib/gstdio.h>
 
-static char *escape_quote(const char *input);
-
 #ifdef USE_SQLITE
+static char *escape_quote(const char *input);
 static sqlite3 *gcompris_db=NULL;
 #endif
 
@@ -262,7 +260,7 @@ int gc_db_init()
     }
 
 
-    request = g_strdup_printf("INSERT INTO class (class_id, name, teacher, wholegroup_id) VALUES ( 1, \'%s\', \'(%s)\', 1);",
+    request = g_strdup_printf("INSERT INTO class (class_id, name, teacher, wholegroup_id) VALUES ( 1, \"%s\", \"(%s)\", 1);",
 			      _("Unaffected"),
 			      _("Users without a class"));
 
@@ -1944,6 +1942,7 @@ void gc_db_log(gchar *date, int duration,
 /* \brief SQL Requires single ' to be replaced by ''
  *
  */
+#ifdef USE_SQLITE
 static char *
 escape_quote(const char *input)
 {
@@ -1967,4 +1966,4 @@ escape_quote(const char *input)
     }
   return result;
 }
-
+#endif
